@@ -39,14 +39,19 @@ class DomainCreate(BaseModel):
   name: str
   description: str
   category: DomainCategory
+  tags: List[int]
 
 class DomainUpdate(BaseModel):
   name: str
   description: str
   category: DomainCategory
+  tags: List[int]
 
-class Domain(DomainCreate):
+class Domain(BaseModel):
   id: int
+  name: str
+  description: str
+  category: DomainCategory
   tags: List[Tag]
   class Config:
     orm_mode = True
