@@ -77,8 +77,8 @@ class JobModel(Base):
   profile_id = Column(Integer, ForeignKey("profiles.id"))
   key_id = Column(Integer, ForeignKey("keys.id"))
   report_id = Column(Integer, ForeignKey("reports.id"), nullable=True)
-  profile = relationship("ProfileModel")
-  key = relationship("APIKeyModel")
-  report = relationship("ReportModel")
+  profile = relationship("ProfileModel", lazy='subquery')
+  key = relationship("APIKeyModel", lazy='subquery')
+  report = relationship("ReportModel", lazy='subquery')
   plugins = relationship("PluginModel", secondary=Job_Plugin_Table)
   cses = relationship("CSEModel", secondary=Job_CSE_Table)
