@@ -41,5 +41,5 @@ class LinkModel(Base):
   snippet = Column(String)
   screenshot = Column(String)
   domain_id = Column(Integer, ForeignKey("domains.id"))
-  domain = relationship("DomainModel")
+  domain = relationship("DomainModel", lazy='subquery')
   tags = relationship("TagModel", secondary=Link_Tag_Table)
