@@ -1,5 +1,8 @@
+from enum import Enum
 from typing import List
 
+import sqlalchemy
+
 from pydantic import BaseModel 
 from sqlalchemy import Column, String, Integer, ForeignKey, Table
 from sqlalchemy.orm import relationship
@@ -16,11 +19,21 @@ Plugin_Tag_Table = Table(
 )
 
 
+class PluginStatus(Enum):
+  ENABLED = "ENABLED"
+  DISABLED = "DISABLED"
+
+
 class PluginCreate(BaseModel):
   urn: str
   description: str
   author: str
   path: str
+  status: PluginStatus
+
+
+class PluginUpdate(BaseModel):
+  status: PluginStatus
 
 
 class Plugin(PluginCreate):
@@ -37,4 +50,5 @@ class PluginModel(Base):
   description = Column(String)
   author = Column(String)
   path = Column(String)
+  status = Column(sqlalchemy.Enum(PluginStatus))
   tags = relationship("TagModel", secondary=Plugin_Tag_Table)
