@@ -6,6 +6,7 @@ from poindexter.models import Base
 
 class PluginOutputCreate(BaseModel):
   path: str
+  source: str
 
 
 class PluginOutput(PluginOutputCreate):
@@ -19,3 +20,4 @@ class PluginOutputModel(Base):
   __tablename__ = 'outputs'
   id = Column(Integer, primary_key=True, index=True)
   path = Column(String)
+  source = Column(String)
