@@ -18,10 +18,15 @@ Profile_Keyword_Table = Table(
 
 class ProfileCreate(BaseModel):
   name: str
+  keywords: List[int]
 
+class ProfileUpdate(BaseModel):
+  name: str
+  keywords: List[int]
 
-class Profile(ProfileCreate):
+class Profile(BaseModel):
   id: int
+  name: str
   keywords: List[Keyword]
   class Config:
     orm_mode = True
